Moving from Paragraphs 7.x-1.0-rc3 to 7.x-1.0-rc3+4-dev results in a significant performance degradation. Adding and removing paragrahs items would previously take about 1.5 seconds in my test environment, but after the update this increases to 6-12 seconds. This can be a significant UX issue.

CommentFileSizeAuthor
#3 performance_degredation-2569807-3.patch443 bytesjstoller

Comments

jstoller created an issue. See original summary.

jeroen.b’s picture

Is this caused by your patch from https://www.drupal.org/node/2562875? (can you test pre-patch?)

jstoller’s picture

Status: Active » Needs review
StatusFileSize
new443 bytes

This appears to fix the issue.

jstoller’s picture

Status: Needs review » Reviewed & tested by the community
Related issues: +#2568455: Upgrading to 7.x-1.0-rc3+4-dev Caused Ajax Errors

I'm marking this RTBC, based on the independent testing done in #2568455: Upgrading to 7.x-1.0-rc3+4-dev Caused Ajax Errors.

jstoller’s picture

Priority: Normal » Major

Bumping this to major since it has broad impact and seems to be causing a variety of odd errors for people.

jeroen.b’s picture

Status: Reviewed & tested by the community » Closed (duplicate)
jstoller’s picture

@jeroen.b, no problem, but I'd suggest you consider committing this patch anyway. It's a small inconsequential change and I think it's triggering a whole bunch of crazy errors that risk flooding your issue queue.

jenlampton’s picture

Status: Closed (duplicate) » Reviewed & tested by the community

setting back to RTBC as per last comment (feel free to change back if desired)

jstoller’s picture

Status: Reviewed & tested by the community » Closed (outdated)

An earlier commit negated this patch and I believe the original problem was fixed, so closing this issue.